searchData={"content_type":"text/markdown","items":[{"doc":"It's a map format verifier, verify if keys/values exist in a given map, short and quick, you can specify more than one\nformat and verify list of values.\n\nJust use the function [`MapSchemaValidator.validate/2`](https://hexdocs.pm) or [`MapSchemaValidator.validate!/2`](https://hexdocs.pm)","ref":"MapSchemaValidator.html","title":"MapSchemaValidator","type":"module"},{"doc":"By param schema validates the param data and compares the format and values to ensure follows a specific format.","ref":"MapSchemaValidator.html#validate/2","title":"MapSchemaValidator.validate/2","type":"function"},{"doc":"iex> MapSchemaValidator.validate(%{key: :string}, %{key: \"value\"})\n    {:ok, nil}\n\n    iex> MapSchemaValidator.validate(%{key: [:string, :number]}, %{key: 1})\n    {:ok, nil}\n\n    iex> MapSchemaValidator.validate(%{key: [%{inner_key: :string}]}, %{key: [%{inner_key: \"value_1\"}, %{inner_key: \"value_2\"}]})\n    {:ok, nil}\n\n    iex> MapSchemaValidator.validate(%{key: [%{inner_key: :string}]}, %{key: [%{inner_key: 1}, %{inner_key: \"value_2\"}]})\n    {:error, %MapSchemaValidator.InvalidMapError{message: \"error at: key -> inner_key\"}}","ref":"MapSchemaValidator.html#validate/2-examples","title":"Examples - MapSchemaValidator.validate/2","type":"function"},{"doc":"Same as MapSchemaValidator.validate/2 but raises in fail.","ref":"MapSchemaValidator.html#validate!/2","title":"MapSchemaValidator.validate!/2","type":"function"},{"doc":"iex> MapSchemaValidator.validate!(%{key: :string}, %{key: \"value\"})\n    :ok\n\n    iex> MapSchemaValidator.validate!(%{key: [:string, :number]}, %{key: 1})\n    :ok\n\n    iex> MapSchemaValidator.validate!(%{key: [%{inner_key: :string}]}, %{key: [%{inner_key: \"value_1\"}, %{inner_key: \"value_2\"}]})\n    :ok\n\n    iex> MapSchemaValidator.validate!(%{key: [%{inner_key: :string}]}, %{key: [%{inner_key: 1}, %{inner_key: \"value_2\"}]})\n    ** (MapSchemaValidator.InvalidMapError) error at: key -> inner_key","ref":"MapSchemaValidator.html#validate!/2-examples","title":"Examples - MapSchemaValidator.validate!/2","type":"function"},{"doc":"Documentation for `MapSchemaValidator`.","ref":"MapSchemaValidator.MapUtils.html","title":"MapSchemaValidator.MapUtils","type":"module"},{"doc":"Transforms maps with key-strings to maps with atom-strings.","ref":"MapSchemaValidator.MapUtils.html#map_to_atom_keys/1","title":"MapSchemaValidator.MapUtils.map_to_atom_keys/1","type":"function"},{"doc":"iex> MapSchemaValidator.MapUtils.map_to_atom_keys(%{\"key\" => \"value\"})\n    %{key: \"value\"}","ref":"MapSchemaValidator.MapUtils.html#map_to_atom_keys/1-examples","title":"Examples - MapSchemaValidator.MapUtils.map_to_atom_keys/1","type":"function"},{"doc":"","ref":"MapSchemaValidator.InvalidMapError.html","title":"MapSchemaValidator.InvalidMapError","type":"exception"},{"doc":"# map_schema_validator\n\nIt's a map format verifier, verify if keys/values exist in a given map, short and quick, you can specify more than one \nformat and verify list of values.\n\nThe motivation of create this library was verify that a json file content has a specific format and fail in case that \nnot matches raises an error with the route to the invalid field\n\n[Docs here!](https://hexdocs.pm/map_schema_validator)","ref":"readme.html","title":"map_schema_validator","type":"extras"},{"doc":"If [available in Hex](https://hex.pm/packages/map_schema_validator/0.1.6), the package can be installed\nby adding `map_schema_validator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:map_schema_validator, \"~> 0.1.6\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - map_schema_validator","type":"extras"},{"doc":"Just use the function [`MapSchemaValidator.validate/2`](https://hexdocs.pm/map_schema_validator/0.1.6/MapSchemaValidator.html#validate/2) \nor [`MapSchemaValidator.validate!/2`](https://hexdocs.pm/map_schema_validator/0.1.6/MapSchemaValidator.html#validate!/2)\n\n##","ref":"readme.html#usage","title":"Usage - map_schema_validator","type":"extras"},{"doc":"```elixir\nschema = %{\n  field: %{\n    inner_field: :string\n  }\n}\nmap = %{\n  field: %{\n    inner_field: \"value\"\n  }\n}\n\ncase MapSchemaValidator.validate(schema, map) do\n  {:ok, _} ->\n    :ok\n    # your stuff\n  {:error, %MapSchemaValidator.InvalidMapError{message: message}} ->\n    :error\n    # failure\nend\n\ntry do\n  :ok = MapSchemaValidator.validate!(schema, map)\nrescue\n  e in MapSchemaValidator.InvalidMapError -> \n    e.message\nend\n```\n\n##","ref":"readme.html#basic-usage","title":"Basic usage - map_schema_validator","type":"extras"},{"doc":"You can check inner list of maps or even list of possible values, or even optional values using `?` at the end of the\nfield name in the schema\n\n```\n:float, :integer, :number, :boolean, :string, [:list], %{type: :map}, [%{type: :map}]\n```\n\n> the list of maps `[%{type: :map}]` are just valid with one object schema, in this case you are validating that an list\n> has the format of the map, but only it's supported one element, multiple object schema options are in backlog\n\n**Primitive types**\n\n```elixir\nschema = %{\n  value_number: :number,\n  value_float: :float,\n  value_integer: :integer,\n  value_boolean: :boolean,\n  value_string: :string\n}\nmap = %{\n  value_number: 1,\n  value_float: 1.1,\n  value_integer: 1,\n  value_boolean: false,\n  value_string: \"value string\"\n}\n\n{:ok, _} = MapSchemaValidator.validate(schema, map)\n```\n\n**Optional keys**\n\n```elixir\nschema = %{\n  mandatory_value: :string,\n  optional_value?: :number\n}\nmap = %{\n  mandatory_value: \"value string\"\n}\n\n{:ok, _} = MapSchemaValidator.validate(schema, map)\n```\n\n> Just adding the `?` char at the end of the key (like Typescript)\n\n**Nested Maps**\n\n```elixir\nschema = %{\n  value_map: %{\n    inner_map: %{\n      inner_value: :string\n    }\n  }\n}\nmap = %{\n  value_map: %{\n    inner_map: %{\n      inner_value: \"value string\"\n    }\n  }\n}\n\n{:ok, _} = MapSchemaValidator.validate(schema, map)\n```\n\n**List of allowed values**\n\n```elixir\nschema = %{\n  value_one_of: [:string, :number],\n}\nmap = %{\n  value_one_of: \"value string\",\n}\n\n{:ok, _} = MapSchemaValidator.validate(schema, map)\n\nmap = %{\n  value_one_of: 100,\n}\n\n{:ok, _} = MapSchemaValidator.validate(schema, map)\n```\n\n**List of allowed values and list of values**\n\n```elixir\nschema = %{\n  value_list: [:string, :number],\n}\nmap = %{\n  value_list: [\"value string\", 1],\n}\n\n{:ok, _} = MapSchemaValidator.validate(schema, map)\n```\n\n**List of maps with format**\n\n```elixir\nschema = %{\n  list: [\n    %{\n      inner_value: :string,\n      inner_map: %{\n        inner_value: :string\n      },\n      inner_list: [\n        %{\n          inner_value_level_2: :number\n        }\n      ]\n    }  \n  ]\n}\nmap = %{\n  list: [\n    %{\n      inner_value: \"value string\",\n      inner_map: %{\n        inner_value: \"value string\"\n      },\n      inner_list: [\n        %{\n          inner_value_level_2: 100\n        }\n      ]\n    }  \n  ]\n}\n\n{:ok, _} = MapSchemaValidator.validate(schema, map)\n```\n\n> In this case are allowed just one schema per list, multiple are work in progress\n\n##","ref":"readme.html#possible-values","title":"Possible values - map_schema_validator","type":"extras"},{"doc":"```elixir\nschema = %{\n  list: [\n    %{\n      inner_field: [:string, :number],\n      inner_list: [\n        %{\n          inner_leven_2_flag: [:boolean, :integer]\n        }\n      ],\n      inner_optional_flag?: :boolean\n    }\n  ]\n}\nmap = %{\n  list: [\n    %{\n      inner_field: \"value string\",\n      inner_list: [\n        %{\n          inner_leven_2_flag: true\n        }\n      ],\n      inner_optional_flag: false\n    },\n    %{\n      inner_field: 10,\n      inner_list: [\n        %{\n          inner_leven_2_flag: true\n        }\n      ]\n    }\n  ]\n}\n\n{:ok, _} = MapSchemaValidator.validate(schema, map)\n```","ref":"readme.html#advanced-example","title":"Advanced example - map_schema_validator","type":"extras"}]}